@@ -277,7 +277,7 @@ pref("ldap_2.servers.history.isOffline",						false);
 // default mapping of addressbook properties to ldap attributes
 pref("ldap_2.servers.default.attrmap.FirstName", "givenName");
 pref("ldap_2.servers.default.attrmap.LastName", "sn,surname");
-pref("ldap_2.servers.default.attrmap.DisplayName", "displayName,cn,commonname");
+pref("ldap_2.servers.default.attrmap.DisplayName", "cn,commonname");
 pref("ldap_2.servers.default.attrmap.NickName", "mozillaNickname,xmozillanickname");
 pref("ldap_2.servers.default.attrmap.PrimaryEmail", "mail");
 pref("ldap_2.servers.default.attrmap.SecondEmail", "mozillaSecondEmail,xmozillasecondemail");
@@ -659,9 +659,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 669 "/home/robert/tinderbox/SeaMonkey/Linux_2.4.21-297-default_Depend/mozilla/mailnews/mailnews.js"
+//@line 669 "/home/robert/tinderbox/SeaMonkey-1.8.0/Linux_2.4.21-297-default_Depend/mozilla/mailnews/mailnews.js"
 
-//@line 672 "/home/robert/tinderbox/SeaMonkey/Linux_2.4.21-297-default_Depend/mozilla/mailnews/mailnews.js"
+//@line 672 "/home/robert/tinderbox/SeaMonkey-1.8.0/Linux_2.4.21-297-default_Depend/mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -678,5 +678,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-//@line 691 "/home/robert/tinderbox/SeaMonkey/Linux_2.4.21-297-default_Depend/mozilla/mailnews/mailnews.js"
+//@line 691 "/home/robert/tinderbox/SeaMonkey-1.8.0/Linux_2.4.21-297-default_Depend/mozilla/mailnews/mailnews.js"
 
